/**
 * This package provides base functionality useful for building React visualizations on top of GoodData.
 *
 * @remarks
 * The functionality includes functions for getting data from the Analytical Backend,
 * components and React hooks that serve as building blocks for custom visualizations,
 * visualization definition placeholders, support for drilling, and so on.
 *
 * See the other `@gooddata/sdk-ui-*` packages (for example, `@gooddata/sdk-ui-charts`) for pre-built visualizations
 * that you can use instead of building your own.
 *
 * @packageDocumentation
 */
export * from "./base/index.js";
export * from "./execution/index.js";
export * from "./kpi/index.js";
export * from "./locales.js";
/**
 * Common interface uses to specify number separators for the different SDK components.
 * @public
 */
export type { ISeparators } from "@gooddata/sdk-model";
export { CorrelationProvider, useCorrelationData, useBackendWithCorrelation, BackendProviderWithCorrelation, } from "./base/react/CorrelationContext.js";
export type { ICorrelationProviderProps, IBackendProviderWithCorrelationProps, } from "./base/react/CorrelationContext.js";
//# sourceMappingURL=index.d.ts.map